@@ -1,4 +1,5 @@
 import requests
+from requests.exceptions import MissingSchema
 from typing import Union
 from ...base import Base2Vec
 from ...import_utils import is_all_dependency_installed
@@ -10,16 +11,17 @@ if is_all_dependency_installed('encoders-image'):
     import matplotlib.pyplot as plt
     from urllib.request import urlopen, Request
     from skimage import transform
+    from PIL import Image
 
 class BaseImage2Vec(Base2Vec):
     def read(self, image: str):
         """
-            An method to read images. 
+            An method to read images (converting them into NumPy arrays)
             Args:
                 image: An image link/bytes/io Bytesio data format.
                 as_gray: read in the image as black and white
         """
-        if type(image) == str:
+        if type(image) is str:
             if 'http' in image:
                 try:
                     b = io.BytesIO(urlopen(Request(
@@ -29,18 +31,33 @@ class BaseImage2Vec(Base2Vec):
                     return tf.image.decode_jpeg(requests.get(image).content, channels=3, name="jpeg_reader").numpy()
             else:
                 b = image
-        elif type(image) == bytes:
+        elif type(image) is bytes:
             b = io.BytesIO(image)
-        elif type(image) == io.BytesIO:
+        elif type(image) is io.BytesIO:
             b = image
         else:
             raise ValueError("Cannot process data type. Ensure it is is string/bytes or BytesIO.")
         try:
             return np.array(imageio.imread(b, pilmode="RGB"))
-        # TODO: Flesh out exceptions
         except:
             return np.array(imageio.imread(b)[:, :, :3])
-    
+
+    def is_greyscale(self, img_path: str):
+        """Determine if an image is grayscale or not
+        """
+        try:
+            img = Image.open(requests.get(img_path, stream=True).raw)
+        except MissingSchema:
+            img = Image.open(img_path)
+        img = img.convert('RGB')
+        w, h = img.size
+        for i in range(w):
+            for j in range(h):
+                r, g, b = img.getpixel((i,j))
+                if r != g != b: 
+                    return False
+        return True
+
     def to_grayscale(self, sample, rgb_weights: list=None):
         """
             Converting an image from RGB to Grayscale
